@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: clamav-update.pl,v 1.38 2007/07/14 21:09:07 okamura Exp $
+# $Id: clamav-update.pl,v 1.41 2007/12/13 01:29:12 okamura Exp $
 
 =head1 NAME
 
@@ -525,9 +525,9 @@ sub CheckSecurity {
 #		download file name format is xxxx-1.2.3.tar.gz
 #		extracted directory name format is xxxx-1.2.3
 #	SAMPLE CONFIGUREATION:
-#		$Setting{version}->{latest}->{command} = <mthod of your software>;
+#		$Setting{version}->{latest}->{command} = <method of your software>;
 #		$Setting{version}->{latest}->{regexp} = qr/regexp for above/;
-#		$Setting{version}->{current}->{command} = <mthod of your software>;
+#		$Setting{version}->{current}->{command} = <method of your software>;
 #		$Setting{version}->{current}->{regexp} = qr/regexp for above/;
 #		$Setting{option}->{src} = '<Base URL for your software>';
 #		$Setting{option}->{name} = '<Name of your software>';
@@ -664,7 +664,7 @@ sub PhaseSpecifier4ClamAV4ClamXav {
 #		dmg file name format is xxxx-1.2.3.dmg
 #		pkg file name format is xxxx-1.2.3.pkg
 #	SAMPLE CONFIGUREATION:
-#		$Setting{version}->{latest}->{command} = <mthod of your software>;
+#		$Setting{version}->{latest}->{command} = <method of your software>;
 #		$Setting{version}->{latest}->{regexp} = qr/regexp for above/;
 #		$Setting{version}->{current}->{command} = sub {
 #			my  $newestVer;
@@ -702,33 +702,34 @@ sub PhaseSpecifier4PkgOnDmg {
 	$Phase{attach}->{workdir} = undef;
 	$Phase{attach}->{method} = [
 		['hdiutil', 'attach',
+			'-mountpoint', $Setting{option}->{dst},
 			"$Setting{option}->{dst}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}"
 		],
 	];
 	$Phase{attach}->{rollback} = [
-		['hdiutil', 'detach',
-			"/Volumes/$Setting{option}->{name}-$LatestVersion"
+		['hdiutil', 'detach', '-force',
+			$Setting{option}->{dst}
 		],
 	];
 
 	$Phase{install}->{workdir} = undef;
 	$Phase{install}->{method} = [
 		['installer', '-pkg',
-			"/Volumes/$Setting{option}->{name}-$LatestVersion/$Setting{option}->{name}-$LatestVersion.pkg",
+			"$Setting{option}->{dst}/$Setting{option}->{name}-$LatestVersion.pkg",
 			'-target', '/'
 		],
 	];
 	$Phase{install}->{rollback} = [
-		['hdiutil', 'detach',
-			"/Volumes/$Setting{option}->{name}-$LatestVersion"
+		['hdiutil', 'detach', '-force',
+			$Setting{option}->{dst}
 		],
 	];
 
 	$Phase{detach} = {};
 	$Phase{detach}->{workdir} = undef;
 	$Phase{detach}->{method} = [
-		['hdiutil', 'detach',
-			"/Volumes/$Setting{option}->{name}-$LatestVersion"
+		['hdiutil', 'detach', '-force',
+			$Setting{option}->{dst}
 		],
 	];
 	$Phase{detach}->{rollback} = [
@@ -807,10 +808,10 @@ sub PhaseSpecifier4ClamavUpdate {
 	PhaseSpecifier4ClamavUpdate4ClamXav();
 
 	$Phase{install}->{method} = [
-		[qw(install -bp -o root -g root -m 0755 clamav-update.pl
+		[qw(install -bp -o 0 -g 0 -m 0755 clamav-update.pl
 			/usr/local/bin/clamav-update.pl
 		)],
-		[qw(install -bp -o root -g root -m 0664 clamav-update-update.conf
+		[qw(install -bp -o 0 -g 0 -m 0664 clamav-update-update.conf
 			/usr/local/etc/clamav-update-update.conf
 		)],
 	];
@@ -822,7 +823,7 @@ sub PhaseSpecifier4ClamavUpdate {
 #-------------------------------------------------------------------------------
 # グローバル変数初期値
 #-------------------------------------------------------------------------------
-$Version = 'clamav-update.pl v2.2.3';
+$Version = 'clamav-update.pl v2.2.4';
 
 %ErrorCode = (
 	arguments		=> 1,
@@ -1180,6 +1181,12 @@ Reference of Configuration: L<http://clamav-update.sourceforge.jp/docs/clamav-up
 
 =over 4
 
+=item v2.2.4
+
+ * The function PhaseSpecifier4ClamavUpdate is improved for FreeBSD 6.2.
+ * The function PhaseSpecifier4PkgOnDmg is improved to attach dmg file to unique
+   mount point.
+
 =item v2.2.3
 
  * Update POD based fu7mu4's translation.
