@@ -17,7 +17,7 @@ UsingFreshclam=0
 FreshclamRestartCommand='[qw(/etc/rc.d/init.d/freshclam restart)]'
 ClamavDownloadFrom=http://jaist.dl.sourceforge.net/sourceforge/clamav
 DownloadFrom=http://osdn.dl.sourceforge.jp/clamav-update
-AdminGroup=root
+AdminGroup=0
 
 
 #### Check Source Directory ####
@@ -66,28 +66,32 @@ Known values for OPTION are:
                 Asia: Tainan, Taiwan
             http://optusnet.dl.sourceforge.net/sourceforge/clamav
                 Australia: Sydney, Australia
-            http://surfnet.dl.sourceforge.net/sourceforge/clamav
-                Europe: Amsterdam, The Netherlands
             http://belnet.dl.sourceforge.net/sourceforge/clamav
                 Europe: Brussels, Belgium
-            http://heanet.dl.sourceforge.net/sourceforge/clamav
-                Europe: Dublin, Ireland
-            http://mesh.dl.sourceforge.net/sourceforge/clamav
-                Europe: Duesseldorf, Germany
-            http://kent.dl.sourceforge.net/sourceforge/clamav
-                Europe: Kent, UK
             http://switch.dl.sourceforge.net/sourceforge/clamav
                 Europe: Lausanne, Switzerland
-            http://ovh.dl.sourceforge.net/sourceforge/clamav
-                Europe: Paris, France
+            http://puzzle.dl.sourceforge.net/sourceforge/clamav
+                Europe: Bern, Switzerland
+            http://mesh.dl.sourceforge.net/sourceforge/clamav
+                Europe: Duesseldorf, Germany
+            http://dfn.dl.sourceforge.net/sourceforge/clamav
+                Europe: Berlin, Germany
+            http://heanet.dl.sourceforge.net/sourceforge/clamav
+                Europe: Dublin, Ireland
+            http://garr.dl.sourceforge.net/sourceforge/clamav
+                Europe: Bologna, Italy
+            http://surfnet.dl.sourceforge.net/sourceforge/clamav
+                Europe: Amsterdam, The Netherlands
+            http://kent.dl.sourceforge.net/sourceforge/clamav
+                Europe: Kent, UK
             http://superb-east.dl.sourceforge.net/sourceforge/clamav
                 North America: McLean, Virginia
-            http://umn.dl.sourceforge.net/sourceforge/clamav
-                North America: Minneapolis, MN
-            http://easynews.dl.sourceforge.net/sourceforge/clamav
-                North America: Phoenix, AZ
             http://superb-west.dl.sourceforge.net/sourceforge/clamav
                 North America: Seattle, Washington
+            http://internap.dl.sourceforge.net/sourceforge/clamav
+                North America: San Jose, CA
+            http://easynews.dl.sourceforge.net/sourceforge/clamav
+                North America: Phoenix, AZ
             http://ufpr.dl.sourceforge.net/sourceforge/clamav
                 South America: Curitiba, Brazil
     --download-from=URL
@@ -98,11 +102,13 @@ Known values for OPTION are:
                 Tokyo Japan: OSDN Japan
             'http://keihanna.dl.sourceforge.jp/clamav-update'
                 Keihanna Japan: Kansai Science City Internet Community
-            'http://qgpop.dl.sourceforge.jp/clamav-update'
-                Fukuoka Japan: Kyushu GigaPOP Project
+            'http://globalbase.dl.sourceforge.jp/clamav-update'
+                Osaka Japan: GLOBALBASE
+            'http://jaist.dl.sourceforge.jp/clamav-update'
+                Ishikawa Japan: Japan Advanced Institute of Science and Technology
     --admin-group=NAME
-        Change administrator UNIX group.
-        default: root
+        Change administrator UNIX group ID.
+        default: 0
     --verbose
         Run as verbose mode.
         In verbose mode, this script displays what executed.
@@ -118,7 +124,7 @@ EOF
 clamavPhaseSpecifier () {
 	if [ $UsingClamd -eq 0 ]; then
 		if [ $UsingFreshclam -eq 0 ]; then
-			if [ "$ClamavPrefix" == '/usr/local/clamXav' ]; then
+			if [ "$ClamavPrefix" = '/usr/local/clamXav' ]; then
 				#### !clamd & !freshclam & ClamXav ####
 				cat <<EOF
 #\$Setting{phase}->{specifier} = \&PhaseSpecifier4ClamAV4ClamXav;
@@ -146,7 +152,7 @@ clamavPhaseSpecifier () {
 #   1;
 #};
 EOF
-			elif [ "$ClamavPrefix" == '/usr/local' ]; then
+			elif [ "$ClamavPrefix" = '/usr/local' ]; then
 				#### !clamd & !freshclam & normal ClamAV ####
 				cat <<EOF
 \$Setting{phase}->{specifier} = \&PhaseSpecifier4General;
@@ -201,7 +207,7 @@ EOF
 EOF
 			fi
 		else
-			if [ "$ClamavPrefix" == '/usr/local/clamXav' ]; then
+			if [ "$ClamavPrefix" = '/usr/local/clamXav' ]; then
 				#### !clamd & freshclam & ClamXav ####
 				cat <<EOF
 \$Setting{phase}->{specifier} = sub {
@@ -225,7 +231,7 @@ EOF
     1;
 };
 EOF
-			elif [ "$ClamavPrefix" == '/usr/local' ]; then
+			elif [ "$ClamavPrefix" = '/usr/local' ]; then
 				#### !clamd & freshclam & normal ClamAV ####
 				cat <<EOF
 \$Setting{phase}->{specifier} = sub {
@@ -277,7 +283,7 @@ EOF
 		fi
 	else
 		if [ $UsingFreshclam -eq 0 ]; then
-			if [ "$ClamavPrefix" == '/usr/local/clamXav' ]; then
+			if [ "$ClamavPrefix" = '/usr/local/clamXav' ]; then
 				#### clamd & !freshclam & ClamXav ####
 				cat <<EOF
 \$Setting{phase}->{specifier} = sub {
@@ -301,7 +307,7 @@ EOF
     1;
 };
 EOF
-			elif [ "$ClamavPrefix" == '/usr/local' ]; then
+			elif [ "$ClamavPrefix" = '/usr/local' ]; then
 				#### clamd & !freshclam & normal ClamAV ####
 				cat <<EOF
 \$Setting{phase}->{specifier} = sub {
@@ -351,7 +357,7 @@ EOF
 EOF
 			fi
 		else
-			if [ "$ClamavPrefix" == '/usr/local/clamXav' ]; then
+			if [ "$ClamavPrefix" = '/usr/local/clamXav' ]; then
 				#### clamd & freshclam & ClamXav ####
 				cat <<EOF
 \$Setting{phase}->{specifier} = sub {
@@ -374,7 +380,7 @@ EOF
     1;
 };
 EOF
-			elif [ "$ClamavPrefix" == '/usr/local' ]; then
+			elif [ "$ClamavPrefix" = '/usr/local' ]; then
 				#### clamd & freshclam & normal ClamAV ####
 				cat <<EOF
 \$Setting{phase}->{specifier} = sub {
@@ -521,7 +527,7 @@ else
 	echo "Use absolute path for --prefix option: $Prefix" 1>&2
 	exit 3
 fi
-if [ "$Prefix" == '' ]; then
+if [ "$Prefix" = '' ]; then
 	echo "Don't use --prefix=/" 1>&2
 	exit 3
 elif [ \! -d "$Prefix/" ]; then
@@ -572,12 +578,12 @@ rm -f "$tempfile1" "$tempfile2"
 
 #--- Install /etc/clamav-update-update.conf ---#
 if [ "$Prefix" != '/usr/local/clamXav' ]; then
-	if [ $Prefix == '/' -o $Prefix == '/usr' ]; then
+	if [ $Prefix = '/' -o $Prefix = '/usr' ]; then
 		echo "\$Setting{environment}->{PATH} = '/bin:/sbin:/usr/bin:/usr/sbin';" >> "$tempfile1"
 	else
 		echo "\$Setting{environment}->{PATH} = '/bin:/sbin:/usr/bin:/usr/sbin:$qtPrefix/bin';" >> "$tempfile1"
 	fi
-	if [ "$Prefix" == '/usr/local' ]; then
+	if [ "$Prefix" = '/usr/local' ]; then
 		echo "\$Setting{phase}->{specifier} = \&PhaseSpecifier4ClamavUpdate;" >> "$tempfile1"
 	else
 		cat <<EOF >> "$tempfile1"
@@ -585,10 +591,10 @@ if [ "$Prefix" != '/usr/local/clamXav' ]; then
 	PhaseSpecifier4ClamAV4ClamXav();
 
 	\$Phase{install}->{method} = [
-		[qw(install -bp -o root -g root -m 0755 clamav-update.pl),
+		[qw(install -bp -o 0 -g '$AdminGroup' -m 0755 clamav-update.pl),
 			'$qtPrefix/bin/clamav-update.pl'
 		)],
-		[qw(install -bp -o root -g root -m 0664 clamav-update-update.conf),
+		[qw(install -bp -o 0 -g '$AdminGroup' -m 0664 clamav-update-update.conf),
 			'$qtPrefix/etc/clamav-update-update.conf'
 		)],
 	];
@@ -612,37 +618,37 @@ if [ -f "$tempfile1" ]; then
 	fi
 
 	if [ $verbose -gt 0 ]; then
-		echo "install -bp -o root -g \"$AdminGroup\" -m 0664 \"$tempfile1\" \"/etc/clamav-update-update.conf\""
+		echo "install -bp -o 0 -g \"$AdminGroup\" -m 0664 \"$tempfile1\" \"/etc/clamav-update-update.conf\""
 	fi
 	if [ $debug -gt 0 ]; then
 		view "$tempfile1"
 	else
-		install -bp -o root -g "$AdminGroup" -m 0664 "$tempfile1" "/etc/clamav-update-update.conf"
+		install -bp -o 0 -g "$AdminGroup" -m 0664 "$tempfile1" "/etc/clamav-update-update.conf"
 	fi
 	rm "$tempfile1"
 fi
 
 #--- Install clamav-update.pl ---#
 if [ $verbose -gt 0 ]; then
-	echo "install -bp -o root -g \"$AdminGroup\" -m 0755 \"$srcdir/clamav-update.pl\" \"$Prefix/bin/clamav-update.pl\""
+	echo "install -bp -o 0 -g \"$AdminGroup\" -m 0755 \"$srcdir/clamav-update.pl\" \"$Prefix/bin/clamav-update.pl\""
 fi
 if [ $debug -eq 0 ]; then
-	install -bp -o root -g "$AdminGroup" -m 0755 "$srcdir/clamav-update.pl" "$Prefix/bin/clamav-update.pl"
+	install -bp -o 0 -g "$AdminGroup" -m 0755 "$srcdir/clamav-update.pl" "$Prefix/bin/clamav-update.pl"
 fi
 
 #--- Install clamav-update.conf ---#
 cat "$srcdir/template/clamav-update.conf" \
 | (
-	if [ "$ClamavPrefix" == '/usr/local/clamXav' ]; then
+	if [ "$ClamavPrefix" = '/usr/local/clamXav' ]; then
 		sed "s/%Path%/#\$Setting{environment}->{PATH} = '\/bin:\/sbin:\/usr\/bin:\/usr\/sbin:\/usr\/local\/clamXav\/bin';/g"
-	elif [ "$ClamavPrefix" == '/' -o "$ClamavPrefix" == '/usr' ]; then
+	elif [ "$ClamavPrefix" = '/' -o "$ClamavPrefix" = '/usr' ]; then
 		sed "s/%Path%/\$Setting{environment}->{PATH} = '\/bin:\/sbin:\/usr\/bin:\/usr\/sbin';/g"
 	else
 		sed "s/%Path%/\$Setting{environment}->{PATH} = '\/bin:\/sbin:\/usr\/bin:\/usr\/sbin:$regClamavPrefix\/bin';/g"
 	fi
 ) \
 | (
-	if [ "$ClamavDownloadFrom" == 'http://jaist.dl.sourceforge.net/sourceforge/clamav' ]; then
+	if [ "$ClamavDownloadFrom" = 'http://jaist.dl.sourceforge.net/sourceforge/clamav' ]; then
 		sed "s/%DownloadFrom%/#\$Setting{option}->{src} = 'http:\/\/jaist.dl.sourceforge.net\/sourceforge\/clamav';/g"
 	else
 		sed "s/%DownloadFrom%/\$Setting{option}->{src} = '$regClamavDownloadFrom';/g"
@@ -665,19 +671,19 @@ while fgrep '%PhaseSpecfier%' "$tempfile1" > /dev/null 2>&1; do
 done
 
 if [ $verbose -gt 0 ]; then
-	echo "install -bp -o root -g \"$AdminGroup\" -m 0664 \"$tempfile1\" \"$Prefix/etc/clamav-update.conf\""
+	echo "install -bp -o 0 -g \"$AdminGroup\" -m 0664 \"$tempfile1\" \"$Prefix/etc/clamav-update.conf\""
 fi
 if [ $debug -gt 0 ]; then
 	view "$tempfile1"
 else
-	install -bp -o root -g "$AdminGroup" -m 0664 "$tempfile1" "$Prefix/etc/clamav-update.conf"
+	install -bp -o 0 -g "$AdminGroup" -m 0664 "$tempfile1" "$Prefix/etc/clamav-update.conf"
 fi
 rm "$tempfile1"
 
 #--- Install clamav-update-update.conf ---#
 if [ $verbose -gt 0 ]; then
-	echo "install -bp -o root -g \"$AdminGroup\" -m 0664 \"$srcdir/clamav-update-update.conf\" \"$Prefix/etc/clamav-update-update.conf\""
+	echo "install -bp -o 0 -g \"$AdminGroup\" -m 0664 \"$srcdir/clamav-update-update.conf\" \"$Prefix/etc/clamav-update-update.conf\""
 fi
 if [ $debug -eq 0 ]; then
-	install -bp -o root -g "$AdminGroup" -m 0664 "$srcdir/clamav-update-update.conf" "$Prefix/etc/clamav-update-update.conf"
+	install -bp -o 0 -g "$AdminGroup" -m 0664 "$srcdir/clamav-update-update.conf" "$Prefix/etc/clamav-update-update.conf"
 fi
